# GMaps Route

GMaps Route is a allows you to create routes for Google Maps directly in Python.
The project enables you to create a route between two locations, add intermediate destinations and specify waypoints (subdestinations) to route-along.

A simple and more complex example can be found in the [examples/](./examples) directory.

## Installation
`pip install gmaps-route`
